{{/*
Expand the name of the chart.
*/}}

{{- define "kcoral.name" -}}
{{- default .Release.Name -}}
{{- end -}}

{{- define "kcoral.namespace" -}}
{{- default .Release.Namespace -}}
{{- end -}}

{{/*
Return the proper kcoral apiserver image name
*/}}
{{- define "kcoral.apiserver.image" -}}
{{ include "common.images.image" (dict "imageRoot" .Values.apiServer.image "global" .Values.global "tag" .Values.global.kcoral) }}
{{- end -}}

{{/*
Return the kcoral apiserver labels
*/}}
{{- define "kcoral.apiserver.labels" -}}
app: {{ include "kcoral.name" . }}-apiserver
component: {{ include "kcoral.name" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ default .Chart.AppVersion $.Values.apiServer.image.tag | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
app.kubernetes.io/part-of: kcoral
{{- if .Values.common.istio.injection }}
sidecar.istio.io/inject: "true"
{{- end }}
{{- if .Values.apiServer.labels }}
{{ toYaml .Values.apiServer.labels }}
{{- end }}
{{- end -}}


{{/*
Return the proper kcoral ui image name
# UI image tag does not roll as the apiserver image tag
*/}}
{{- define "kcoral.ui.image" -}}
{{ include "common.images.image" (dict "imageRoot" .Values.ui.image "global" .Values.global ) }}
{{- end -}}


{{- define "kcoral.ui.labels" -}}
app: {{ include "kcoral.name" . }}-ui
component: {{ include "kcoral.name" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ default .Chart.AppVersion $.Values.ui.image.tag | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
app.kubernetes.io/part-of: kcoral
{{- if .Values.common.istio.injection }}
sidecar.istio.io/inject: "true"
{{- end }}
{{- if .Values.ui.labels }}
{{ toYaml .Values.ui.labels }}
{{- end }}
{{- end -}}

{{/*
Return the proper  kcoral apiserver Image Registry Secret Names
*/}}
{{- define "kcoral.apiserver.imagePullSecrets" -}}
{{ include "common.images.pullSecrets" (dict "images" (list .Values.apiServer.image) "global" .Values.global) }}
{{- end -}}

{{- define "kcoral.apiserver.svcName" -}}
{{- include "kcoral.name" .}}-apiserver
{{- end -}}

{{- define "kcoral.apiserver.command" -}}
- --kpanda-server={{ .Values.apiServer.config.integration.kpanda.server }}
- --kpanda-ingress-server={{ .Values.apiServer.config.integration.kpanda.ingressServer }}
{{- end -}}

/* controller manager */

{{- define "kcoral.controllermanager.imagePullSecrets" -}}
{{ include "common.images.pullSecrets" (dict "images" (list .Values.controllerManager.image) "global" .Values.global) }}
{{- end -}}

{{- define "kcoral.controllermanager.image" -}}
{{ include "common.images.image" (dict "imageRoot" .Values.controllerManager.image "global" .Values.global "tag" .Values.global.kcoral) }}
{{- end -}}